import Utils.IxLoadUtils as IxLoadUtils
import Utils.IxRestUtils as IxRestUtils
import Utils.IxLoadTestSettings as TestSettings
import inspect
from collections import OrderedDict

####TEST CONFIG
testSettings = TestSettings.IxLoadTestSettings()
# testSettings.gatewayServer = "machine_ip_address" #TODO - to be changed by user
testSettings.ixLoadVersion = ""           #TODO - to be changed by user, by default will run on the latest installed version
testSettings.chassisList = ['chassisIpOrHostName']  #TODO - to be changed by user


location=inspect.getfile(inspect.currentframe())


testSettings.portListPerCommunity =    {
                                        "Traffic1@Network1" : [(1,7,1)],
                                        "Traffic2@Network2" : [(1,7,5)]
                                    }

kStatsToDisplayDict =   {
                            #format: { statSource : [stat name list] }
                            "StatelessPeer": ["Active Streams Transmitting","Total Packets Received","Total Packets Sent"]
                        }

kCommunities = [
    # format: {option1: value1, option2: value2}
    {},  # default community with no options
    {"tcpAccelerationAllowedFlag": True}  # community with tcpAccelerationAllowedFlag set to True
]

kActivities = OrderedDict([
    # format: {communityName: [activityProtocolAndType1, activityProtocolAndType2]}
    ('Traffic1@Network1', ['stateless Peer']),
    ('Traffic2@Network2', ['stateless Peer'])
])

#create a connection to the gateway
connection = IxRestUtils.getConnection(
                        testSettings.gatewayServer,
                        testSettings.gatewayPort,
                        httpRedirect=testSettings.httpRedirect,
                        version=testSettings.apiVersion
                        )
sessionUrl = None

try:
    # create a session
    IxLoadUtils.log("Creating a new session...")
    sessionUrl = IxLoadUtils.createNewSession(connection, testSettings.ixLoadVersion)
    IxLoadUtils.log("Session created.")


    # create nettraffics (communities)
    IxLoadUtils.log('Creating communities...')
    IxLoadUtils.addCommunities(connection, sessionUrl, kCommunities)
    IxLoadUtils.log('Communities created.')


    # create activities
    IxLoadUtils.log('Creating activities...')
    IxLoadUtils.addActivities(connection, sessionUrl, kActivities)
    IxLoadUtils.log('Activities created.')

    #Generate IP Stream command
    IxLoadUtils.log('Adding Generate IP Stream command to StatelessPeer1...')
    IxLoadUtils.log('IP in IP encapsulation ...')
    StatelessPeerCommandOptions1 = {'commandType': 'GenerateIPStream', 'remotePeer': 'Traffic2_StatelessPeer2', 'proto':'4','maxPacketFreq': '1000'}
    IxLoadUtils.StatelessPeerUtils.addStatelessPeerCommand(connection, sessionUrl, 'Traffic1@Network1','StatelessPeer1', StatelessPeerCommandOptions1)
    IxLoadUtils.log('Command added to StatelessPeer2 .')

    #Generate UDP Stream command
    IxLoadUtils.log('Adding Generate UDP Stream command to StatelessPeer2...')
    StatelessPeerCommandOptions2 = {'commandType': 'GenerateStream','destination': 'Traffic1_StatelessPeer1','remotePeer': 'Traffic1_StatelessPeer1' }
    IxLoadUtils.StatelessPeerUtils.addStatelessPeerCommand(connection, sessionUrl, 'Traffic2@Network2','StatelessPeer2', StatelessPeerCommandOptions2)
    IxLoadUtils.log('Command added to StatelessPeer1.')


    IxLoadUtils.log("Clearing chassis list...")
    IxLoadUtils.clearChassisList(connection, sessionUrl)
    IxLoadUtils.log("Chassis list cleared.")

    IxLoadUtils.log("Adding chassis %s..." % (testSettings.chassisList))
    IxLoadUtils.addChassisList(connection, sessionUrl, testSettings.chassisList)
    IxLoadUtils.log("Chassis added.")

    IxLoadUtils.log("Assigning new ports...")
    IxLoadUtils.assignPorts(connection, sessionUrl, testSettings.portListPerCommunity)
    IxLoadUtils.log("Ports assigned.")

    IxLoadUtils.log("Saving repository %s..." % (IxLoadUtils.getRxfName(connection, location)))
    IxLoadUtils.saveRxf(connection, sessionUrl, IxLoadUtils.getRxfName(connection, location))
    IxLoadUtils.log("Repository saved.")

    IxLoadUtils.log("Starting the test...")
    IxLoadUtils.runTest(connection, sessionUrl)
    IxLoadUtils.log("Test started.")

    IxLoadUtils.log("Polling values for stats %s..." % (kStatsToDisplayDict))
    IxLoadUtils.pollStats(connection, sessionUrl, kStatsToDisplayDict)

    IxLoadUtils.log("Test finished.")

    IxLoadUtils.log("Checking test status...")
    testRunError = IxLoadUtils.getTestRunError(connection, sessionUrl)
    if testRunError:
        IxLoadUtils.log("The test exited with the following error: %s" % testRunError)
    else:
        IxLoadUtils.log("The test completed successfully.")

    IxLoadUtils.log("Waiting for test to clean up and reach 'Unconfigured' state...")
    IxLoadUtils.waitForTestToReachUnconfiguredState(connection, sessionUrl)
    IxLoadUtils.log("Test is back in 'Unconfigured' state.")
finally:
    if sessionUrl is not None:
        IxLoadUtils.log("Closing IxLoad session...")
        IxLoadUtils.deleteSession(connection, sessionUrl)
        IxLoadUtils.log("IxLoad session closed.")
