
#------------------------------------------------------------------------------
# Name          : reboot_chassis.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs reboot virtual chassis.
# Test Steps    : 1. Add a Card to Chassis & check card status is OK.
#				  2. Reboot the chassis & After wait Check that Card still has OK status. 
#    
#
# Prerequisite  : A Chassis & Card is already deployed & reachable.
#------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Deployed Card IP this this file 
source common.tcl 

#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : reboot_chassis.tcl "
puts "#############################################"

puts ""
puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"
set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder
puts "Getting Chassis Topology & Card Details.."
set topologies [$chassisBuilder getChassisTopology ]
set count      [$topologies indexCount]
puts "This Chassis has Number of Cards = $count"
if {$count != 0} {
    puts "Deleting all existing cards.."
	for {set index 0} {$index < $count} {incr index} {
		set topology     [$topologies getItem $index]
		puts "topology: $topology"
		set CardServerId     [$topology cget -CardServerId]
		$chassisBuilder deleteCard -cardId $CardServerId
    }
}

puts ""
puts "-------------------------------------------------------"
puts "Add new Card ( $cardIP ) to Chassis with one port .."
puts "-------------------------------------------------------"

set CardServerId 1
$chassisBuilder addCard -managementIp $cardIP -cardServerId $CardServerId -keepAliveTimeout 300
set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
$chassisBuilder addPort -cardId $CardServerId -portId 1 -interfaceName "eth1" -promiscMode False
$chassisBuilder connectCard -cardId $CardServerId


puts "Starting getChassisTopology API"
puts "------------------------------------"
set topologies [$chassisBuilder getChassisTopology ]
set count2      [$topologies indexCount]
#for {set index 0} {$index < $count2} {incr index} {
	set index [expr $count2 - 1 ]
	set topology     [$topologies getItem $index]
	puts "topology: $topology"
	set CardServerId     [$topology cget -CardServerId]
	set InterfaceName    [$topology cget -InterfaceName]
	set IPAddress        [$topology cget -IPAddress]
	set KeepAliveTimeout [$topology cget -KeepAliveTimeout]
	set LineSpeed        [$topology cget -LineSpeed]
	set MAC              [$topology cget -MAC]
	set MTU              [$topology cget -MTU]
	set PortServerId     [$topology cget -PortServerId]
	set PromiscMode      [$topology cget -PromiscMode]
	
	puts "CardServerId = $CardServerId"
	puts "InterfaceName = $InterfaceName"
	puts "IPAddress =  $IPAddress"
	puts "KeepAliveTimeout = $KeepAliveTimeout"
	puts "LineSpeed =  $LineSpeed"
	puts "MAC = $MAC"
	puts "MTU = $MTU"
	puts "PortServerId =  $PortServerId"
	puts "PromiscMode =  $PromiscMode"
	
	set cardId [$chassisBuilder getIxVMCardByIP -managementIp $IPAddress]
	set card [$chassisBuilder getCardById -cardId $cardId]

	set CardName              [$card cget -CardName]
	set CardServerId1          [$card cget -CardServerId]
	set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
	set ManagementIp          [$card cget -ManagementIp]
	set Status                [$card cget -Status]
	puts "Card ID: $cardId"
	puts "Card $CardName ID $CardServerId1 with IP $ManagementIp has the status $Status"
	
	puts ""
	puts "---------------------------------------------"
	puts "Reboot the Chassis."
	puts "---------------------------------------------"
	puts "rebooting Chassis...Please Wait ...."
	
	
	$chassisBuilder hardChassisReboot
	after 40000

	set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
	set card [$chassisBuilder getCardById -cardId $cardId]
	set CardName              [$card cget -CardName]
	set CardServerId          [$card cget -CardServerId]
	set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
	set ManagementIp          [$card cget -ManagementIp]
	set Status                [$card cget -Status]
	puts "Card $CardName ID $CardServerId with IP $ManagementIp has the status $Status"
	
#################
#   TEST END    #
#################
::IxLoad disconnect
